summaryrefslogtreecommitdiff
path: root/libavcodec/tak.h
diff options
context:
space:
mode:
Diffstat (limited to 'libavcodec/tak.h')
-rw-r--r--libavcodec/tak.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/libavcodec/tak.h b/libavcodec/tak.h
index 19b1c47521..c752062521 100644
--- a/libavcodec/tak.h
+++ b/libavcodec/tak.h
@@ -30,7 +30,7 @@
#include <stdint.h>
#include "avcodec.h"
-#include "get_bits.h"
+#include "bitstream.h"
#define TAK_FORMAT_DATA_TYPE_BITS 3
#define TAK_FORMAT_SAMPLE_RATE_BITS 18
@@ -145,21 +145,21 @@ int ff_tak_check_crc(const uint8_t *buf, unsigned int buf_size);
/**
* Parse the Streaminfo metadata block.
* @param[in] gb pointer to GetBitContext
* @param[out] s storage for parsed information
*/
-void avpriv_tak_parse_streaminfo(GetBitContext *gb, TAKStreamInfo *s);
+void avpriv_tak_parse_streaminfo(BitstreamContext *bc, TAKStreamInfo *s);
/**
* Validate and decode a frame header.
* @param avctx AVCodecContext to use as av_log() context
* @param[in] gb GetBitContext from which to read frame header
* @param[out] s frame information
* @param log_level_offset log level offset, can be used to silence
* error messages.
* @return non-zero on error, 0 if OK
*/
-int ff_tak_decode_frame_header(AVCodecContext *avctx, GetBitContext *gb,
+int ff_tak_decode_frame_header(AVCodecContext *avctx, BitstreamContext *bc,
TAKStreamInfo *s, int log_level_offset);
#endif /* AVCODEC_TAK_H */
@@ -145,21 +145,21 @@ int ff_tak_check_crc(const uint8_t *buf, unsigned int buf_size);
/**
* Parse the Streaminfo metadata block.
- * @param[in] gb pointer to GetBitContext
+ * @param[in] bc pointer to BitstreamContext
* @param[out] s storage for parsed information
*/
@@ -145,21 +145,21 @@ int ff_tak_check_crc(const uint8_t *buf, unsigned int buf_size);
* Validate and decode a frame header.
* @param avctx AVCodecContext to use as av_log() context
- * @param[in] gb GetBitContext from which to read frame header
+ * @param[in] bc BitstreamContext from which to read frame header
* @param[out] s frame information
* @param log_level_offset log level offset, can be used to silence